/*
 * Copyright 2013-2015 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.springframework.cloud.netflix.feign;

import feign.slf4j.Slf4jLogger;
import org.springframework.boot.autoconfigure.AutoConfigureAfter;
import org.springframework.boot.autoconfigure.condition.ConditionalOnClass;
import org.springframework.cloud.netflix.archaius.ArchaiusAutoConfiguration;
import org.springframework.cloud.netflix.feign.ribbon.FeignRibbonClient;
import org.springframework.cloud.netflix.ribbon.SpringClientFactory;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;

import com.netflix.loadbalancer.ILoadBalancer;

import feign.Client;
import feign.Contract;
import feign.Feign;
import feign.Logger;

/**
 * @author Spencer Gibb
 * @author Julien Roy
 */
@Configuration
@ConditionalOnClass(Feign.class)
@AutoConfigureAfter(ArchaiusAutoConfiguration.class)
public class FeignAutoConfiguration {

	@Bean
	public SpringDecoder feignDecoder() {
		return new SpringDecoder();
	}

	@Bean
	public SpringEncoder feignEncoder() {
		return new SpringEncoder();
	}

	@Bean
	public Logger feignLogger() {
		return new Slf4jLogger();
	}

	@Bean
	public Contract feignContract() {
		return new SpringMvcContract();
	}

	@ConditionalOnClass(ILoadBalancer.class)
	@Configuration
	protected static class RibbonClientConfiguration {
		@Bean
		public Client feignRibbonClient(SpringClientFactory factory) {
			return new FeignRibbonClient(factory);
		}
	}

}
